@@ -3,6 +3,22 @@
 
 #include <atk.h>
 
+/* enumerations from "atkhyperlink.h" */
+GType
+atk_hyperlink_state_flags_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GFlagsValue values[] = {
+      { ATK_HYPERLINK_IS_INLINE, "ATK_HYPERLINK_IS_INLINE", "inline" },
+      { 0, NULL, NULL }
+    };
+    etype = g_flags_register_static ("AtkHyperlinkStateFlags", values);
+  }
+  return etype;
+}
+
+
 /* enumerations from "atkobject.h" */
 GType
 atk_role_get_type (void)
@@ -79,6 +95,10 @@ atk_role_get_type (void)
       { ATK_ROLE_UNKNOWN, "ATK_ROLE_UNKNOWN", "unknown" },
       { ATK_ROLE_VIEWPORT, "ATK_ROLE_VIEWPORT", "viewport" },
       { ATK_ROLE_WINDOW, "ATK_ROLE_WINDOW", "window" },
+      { ATK_ROLE_HEADER, "ATK_ROLE_HEADER", "header" },
+      { ATK_ROLE_FOOTER, "ATK_ROLE_FOOTER", "footer" },
+      { ATK_ROLE_PARAGRAPH, "ATK_ROLE_PARAGRAPH", "paragraph" },
+      { ATK_ROLE_RULER, "ATK_ROLE_RULER", "ruler" },
       { ATK_ROLE_LAST_DEFINED, "ATK_ROLE_LAST_DEFINED", "last-defined" },
       { 0, NULL, NULL }
     };
@@ -109,7 +129,7 @@ atk_layer_get_type (void)
 }
 
 
-/* enumerations from "atkrelation.h" */
+/* enumerations from "atkrelationtype.h" */
 GType
 atk_relation_type_get_type (void)
 {
@@ -123,6 +143,11 @@ atk_relation_type_get_type (void)
       { ATK_RELATION_LABELLED_BY, "ATK_RELATION_LABELLED_BY", "labelled-by" },
       { ATK_RELATION_MEMBER_OF, "ATK_RELATION_MEMBER_OF", "member-of" },
       { ATK_RELATION_NODE_CHILD_OF, "ATK_RELATION_NODE_CHILD_OF", "node-child-of" },
+      { ATK_RELATION_FLOWS_TO, "ATK_RELATION_FLOWS_TO", "flows-to" },
+      { ATK_RELATION_FLOWS_FROM, "ATK_RELATION_FLOWS_FROM", "flows-from" },
+      { ATK_RELATION_SUBWINDOW_OF, "ATK_RELATION_SUBWINDOW_OF", "subwindow-of" },
+      { ATK_RELATION_EMBEDS, "ATK_RELATION_EMBEDS", "embeds" },
+      { ATK_RELATION_EMBEDDED_BY, "ATK_RELATION_EMBEDDED_BY", "embedded-by" },
       { ATK_RELATION_LAST_DEFINED, "ATK_RELATION_LAST_DEFINED", "last-defined" },
       { 0, NULL, NULL }
     };
@@ -168,6 +193,7 @@ atk_state_type_get_type (void)
       { ATK_STATE_TRANSIENT, "ATK_STATE_TRANSIENT", "transient" },
       { ATK_STATE_VERTICAL, "ATK_STATE_VERTICAL", "vertical" },
       { ATK_STATE_VISIBLE, "ATK_STATE_VISIBLE", "visible" },
+      { ATK_STATE_MANAGES_DESCENDANTS, "ATK_STATE_MANAGES_DESCENDANTS", "manages-descendants" },
       { ATK_STATE_LAST_DEFINED, "ATK_STATE_LAST_DEFINED", "last-defined" },
       { 0, NULL, NULL }
     };
